from setuptools import setup

setup(name='savant',
      version='0.2',
      description='Scrape video links from Google Drive',
      url='https://github.com/yowmamasita/savant',
      author='Ben Sarmiento',
      author_email='me@bensarmiento.com',
      license='MIT',
      packages=['savant'],
      zip_safe=True)
